@@ -20,7 +20,9 @@ from fossology.jobs import Jobs
 from fossology.license import LicenseEndpoint
 from fossology.obj import (
     Agents,
+    ApiInfo,
     File,
+    HealthInfo,
     SearchTypes,
     TokenScope,
     Upload,
@@ -78,23 +80,23 @@ def fossology_token(
 
     :Example:
 
-    >>> from fossology import fossology_token
-    >>> from fossology.obj import TokenScope
-    >>> token = fossology_token("https://fossology.example.com", "Me", "MyPassword", "MyToken")
+    >>> from fossology import fossology_token # doctest: +SKIP
+    >>> from fossology.obj import TokenScope # doctest: +SKIP
+    >>> token = fossology_token("https://fossology.example.com", "Me", "MyPassword", "MyToken") # doctest: +SKIP
 
 
     :param url: the URL of the Fossology server
     :param username: name of the user the token will be generated for
     :param password: the password of the user
     :param name: the name of the token
-    :param scope: the scope of the token (default: READ)
-    :param expire: the expire date of the token (default: max. 30 days)
+    :param scope: the scope of the token (default: TokenScope.READ)
+    :param expire: the expire date of the token, e.g. 2019-12-25 (default: max. 30 days)
     :type url: string
     :type username: string
     :type password: string
     :type name: string
-    :type scope: TokenScope (default: TokenScope.READ)
-    :type expire: string, e.g. 2019-12-25
+    :type scope: TokenScope
+    :type expire: string
     :return: the new token
     :rtype: string
     :raises AuthenticationError: if the username or password is incorrect
@@ -135,35 +137,34 @@ class Fossology(Folders, Groups, LicenseEndpoint, Uploads, Jobs, Report):
     :Example:
 
     >>> from fossology import Fossology
-    >>> foss = Fossology(FOSS_URL, FOSS_TOKEN, username)
-
-    .. note::
-
-        The class instantiation exits if the session with the Fossology server
-        can't be established
+    >>> foss = Fossology(FOSS_URL, FOSS_TOKEN, username) # doctest: +SKIP
 
     :param url: URL of the Fossology instance
     :param token: The API token generated using the Fossology UI
-    :param name: The name of the token owner
+    :param name: The name of the token owner (deprecated since API version 1.2.3)
     :type url: str
     :type token: str
-    :type name: str
-    :raises AuthenticationError: if the user couldn't be found
+    :type name: str (deprecated since API version 1.2.3)
+    :raises FossologyApiError: if a REST call failed
+    :raises AuthenticationError: if the user couldn't be authenticated
     """
 
-    def __init__(self, url, token, name):
+    def __init__(self, url, token, name=None):
         self.host = url
         self.token = token
-        self.name = name
         self.users = list()
         self.folders = list()
 
         self.api = f"{self.host}/api/v1"
         self.session = requests.Session()
         self.session.headers.update({"Authorization": f"Bearer {self.token}"})
-
-        self.user = self._auth()
         self.version = self.get_version()
+        if versiontuple(self.version) >= versiontuple("1.3.3"):
+            self.info = self.get_info()
+            self.health = self.get_health()
+
+        self.user = self.get_self(name)
+        self.name = self.user.name
         self.rootFolder = self.detail_folder(self.user.rootFolderId)
         self.folders = self.list_folders()
 
@@ -171,20 +172,40 @@ class Fossology(Folders, Groups, LicenseEndpoint, Uploads, Jobs, Report):
             f"Authenticated as {self.user.name} against {self.host} using API version {self.version}"
         )
 
-    def _auth(self):
+    def get_self(self, name=None):
         """Perform the first API request and populate user variables
 
+        API Endpoint: GET /users/self
+
         :return: the authenticated user's details
         :rtype: User
+        :raises FossologyApiError: if the REST call failed
         :raises AuthenticationError: if the user couldn't be found
         """
-        self.users = self.list_users()
-        for user in self.users:
-            if user.name == self.name:
-                self.user = user
-                return self.user
-        description = f"User {self.name} was not found on {self.host}"
-        raise AuthenticationError(description)
+        if versiontuple(self.version) >= versiontuple("1.2.3"):
+            response = self.session.get(f"{self.api}/users/self")
+            if response.status_code == 200:
+                user_agents = None
+                user_details = response.json()
+                if user_details.get("agents"):
+                    user_agents = Agents.from_json(user_details["agents"])
+                user = User.from_json(user_details)
+                user.agents = user_agents
+                return user
+            else:
+                description = "Error while getting details about authenticated user"
+                raise FossologyApiError(description, response)
+        else:
+            if not name:
+                description = "You need to provide a username to create an API session"
+                raise AuthenticationError(description)
+            self.users = self.list_users()
+            for user in self.users:
+                if user.name == name:
+                    self.user = user
+                    return self.user
+            description = f"User {name} was not found on {self.host}"
+            raise AuthenticationError(description)
 
     def close(self):
         self.session.close()
@@ -192,7 +213,7 @@ class Fossology(Folders, Groups, LicenseEndpoint, Uploads, Jobs, Report):
     def get_version(self):
         """Get API version from the server
 
-        API endpoint: GET /version
+        API endpoint: GET /version (deprecated since API version 1.3.3)
 
         :return: the API version string
         :rtype: string
@@ -205,6 +226,38 @@ class Fossology(Folders, Groups, LicenseEndpoint, Uploads, Jobs, Report):
             description = "Error while getting API version"
             raise FossologyApiError(description, response)
 
+    def get_info(self) -> ApiInfo:
+        """Get info from the server
+
+        API endpoint: GET /info
+
+        :return: the API information
+        :rtype: ApiInfo
+        :raises FossologyApiError: if the REST call failed
+        """
+        response = self.session.get(f"{self.api}/info")
+        if response.status_code == 200:
+            return ApiInfo.from_json(response.json())
+        else:
+            description = "Error while getting API info"
+            raise FossologyApiError(description, response)
+
+    def get_health(self) -> ApiInfo:
+        """Get health from the server
+
+        API endpoint: GET /health
+
+        :return: the server health information
+        :rtype: HealthInfo
+        :raises FossologyApiError: if the REST call failed
+        """
+        response = self.session.get(f"{self.api}/health")
+        if response.status_code == 200:
+            return HealthInfo.from_json(response.json())
+        else:
+            description = "Error while getting health info"
+            raise FossologyApiError(description, response)
+
     def detail_user(self, user_id):
         """Get details of Fossology user.
 
