@@ -8,11 +8,10 @@ from enum import Enum
 class AccessLevel(Enum):
     """Available access levels for uploads:
 
-    PRIVATE: the upload will only be visible to the owner
+    PRIVATE
+    PROTECTED
+    PUBLIC
 
-    PROTECTED: ?
-
-    PUBLIC: the upload will be visible for everyone
     """
 
     PRIVATE = "private"
@@ -21,7 +20,15 @@ class AccessLevel(Enum):
 
 
 class ReportFormat(Enum):
-    """Available report format: DEP5, SPDX2, SPDX2TV, READMEOSS, UNIFIEDREPORT"""
+    """Available report format:
+
+    DEP5
+    SPDX2
+    SPDX2TV
+    READMEOSS
+    UNIFIEDREPORT
+
+    """
 
     DEP5 = "dep5"
     SPDX2 = "spdx2"
@@ -31,7 +38,13 @@ class ReportFormat(Enum):
 
 
 class SearchTypes(Enum):
-    """Type of item that can be searched: ALLFILES, CONTAINERS, DIRECTORIES"""
+    """Type of item that can be searched:
+
+    ALLFILES
+    CONTAINERS
+    DIRECTORIES
+
+    """
 
     ALLFILES = "allfiles"
     CONTAINERS = "containers"
@@ -44,6 +57,7 @@ class TokenScope(Enum):
     READ: Read only access, limited only to "GET" calls
 
     WRITE: Read/Write access, required for calls other than "GET"
+
     """
 
     READ = "read"
@@ -51,15 +65,51 @@ class TokenScope(Enum):
 
 
 class ClearingStatus(Enum):
-    """Clearing statuses
+    """Clearing statuses:
+
+    OPEN
+    INPROGRESS
+    CLOSED
+    REJECTED
+
     """
 
     OPEN = "Open"
-    PROGRESS = "InProgress"
+    INPROGRESS = "InProgress"
     CLOSED = "Closed"
     REJECTED = "Rejected"
 
 
+class LicenseType(Enum):
+    """License types:
+
+    CANDIDATE
+    MAIN
+    ALL
+
+    """
+
+    CANDIDATE = "candidate"
+    MAIN = "main"
+    ALL = "all"
+
+
+class ObligationClass(Enum):
+    """Classification of an obligation:
+
+    GREEN
+    WHITE
+    YELLOW
+    RED
+
+    """
+
+    GREEN = "green"
+    WHITE = "white"
+    YELLOW = "yellow"
+    RED = "red"
+
+
 class Agents(object):
 
     """FOSSology agents.
@@ -312,30 +362,101 @@ class License(object):
 
     Represents a FOSSology license.
 
-    :param id: the ID of the license
     :param shortName: the short name of the license
     :param fullName: the full name of the license
     :param text: the text of the license
+    :param url: URL of the license text
     :param risk: the risk level of the license
+    :param isCandidate: is the license a candidate?
     :param kwargs: handle any other folder information provided by the fossology instance
-    :type id: int
     :type shortName: string
     :type fullName: string
     :type text: string
+    :type url: string
     :type risk: int
+    :type isCandidate: bool
     :type kwargs: key word argument
     """
 
-    def __init__(self, id, shortName, fullName, text, risk, **kwargs):
+    def __init__(
+        self, shortName, fullName, text, url, risk, isCandidate, id=None, **kwargs
+    ):
         self.id = id
         self.shortName = shortName
         self.fullName = fullName
         self.text = text
+        self.url = url
         self.risk = risk
+        self.isCandidate = isCandidate
         self.additional_info = kwargs
 
     def __str__(self):
-        return f"License {self.fullName} - {self.shortName} ({self.id}) with risk level {self.risk}"
+        license_type = "License"
+        if self.isCandidate:
+            license_type = "Candidate license"
+        return f"{license_type} {self.fullName} - {self.shortName} ({self.id}) with risk level {self.risk}"
+
+    def to_dict(self):
+        """Get a directory with the license data
+
+        :return: the license data
+        :rtype: dict
+        """
+        return {
+            "shortName": self.shortName,
+            "fullName": self.fullName,
+            "text": self.text,
+            "url": self.url,
+            "risk": self.risk,
+            "isCandidate": self.isCandidate,
+        }
+
+    @classmethod
+    def from_json(cls, json_dict):
+        return cls(**json_dict)
+
+    def to_json(self) -> str:
+        """Get a JSON object with the license data
+
+        :return: the license data
+        :rtype: JSON
+        """
+        return json.dumps(self.to_dict())
+
+
+class Obligation(object):
+
+    """FOSSology license obligation.
+
+    Represents a FOSSology license obligation.
+
+    :param id: the ID of the obligation
+    :param topic: the topic of the obligation
+    :param type: the type of the obligation
+    :param text: the text of the obligation
+    :param classification: level of attention it should raise in the clearing process
+    :param comment: comment for the obligation
+    :param kwargs: handle any other folder information provided by the fossology instance
+    :type id: int
+    :type topic: string
+    :type type: string
+    :type text: string
+    :type classification: string
+    :type comment: string
+    :type kwargs: key word argument
+    """
+
+    def __init__(self, id, topic, type, text, classification, comment, **kwargs):
+        self.id = id
+        self.topic = topic
+        self.type = type
+        self.text = text
+        self.classification = classification
+        self.comment = comment
+        self.additional_info = kwargs
+
+    def __str__(self):
+        return f"Obligation {self.topic}, {self.type} ({self.id}) is classified {self.classification}"
 
     @classmethod
     def from_json(cls, json_dict):
@@ -635,6 +756,114 @@ class Job(object):
         return cls(**json_dict)
 
 
+class ApiLicense(object):
+
+    """FOSSology API License.
+
+    :param name: name of the API license
+    :param url: link to the license text
+    :type name: string
+    :type url: string
+    """
+
+    def __init__(self, name, url):
+        self.name = name
+        self.url = url
+
+    def __str__(self):
+        return f"API license '{self.name}' ({self.url})"
+
+    @classmethod
+    def from_json(cls, json_dict):
+        return cls(**json_dict)
+
+
+class ApiInfo(object):
+
+    """FOSSology API info.
+
+    Represents the info endpoint of FOSSology API.
+
+    :param name: the name of the API service
+    :param description: additional information
+    :param version: current API version
+    :param security: security methods allowed
+    :param contact: email contact from the API documentation
+    :param license: licensing of the API
+    :type name: string
+    :type description: string
+    :type version: string
+    :type security: list
+    :type contact: string
+    :type license: ApiLicense object
+    :type kwargs: key word argument
+    """
+
+    def __init__(
+        self, name, description, version, security, contact, license, **kwargs
+    ):
+        self.name = name
+        self.description = description
+        self.version = version
+        self.security = security
+        self.contact = contact
+        self.license = ApiLicense.from_json(license)
+        self.additional_info = kwargs
+
+    def __str__(self):
+        return f"FOSSology API {self.name} is deployed with version {self.version}"
+
+    @classmethod
+    def from_json(cls, json_dict):
+        return cls(**json_dict)
+
+
+class Status(object):
+
+    """FOSSology server status
+
+    Represent the status of FOSSology sub-systems
+
+    :param status: the status of the sub-system (OK, ERROR)
+    :type status: string
+    """
+
+    def __init__(self, status):
+        self.status = status
+
+    @classmethod
+    def from_json(cls, json_dict):
+        return cls(**json_dict)
+
+
+class HealthInfo(object):
+
+    """FOSSology server health info.
+
+    Represents the health endpoint of FOSSology API.
+
+    :param status: the overall status of the API service (OK, WARN, ERROR)
+    :param scheduler: the status of the FOSSology scheduler
+    :param db: the status of the FOSSology DB
+    :type status: string
+    :type scheduler: Status object
+    :type db: Status object
+    :type kwargs: key word argument
+    """
+
+    def __init__(self, status, scheduler, db, **kwargs):
+        self.status = status
+        self.scheduler = Status.from_json(scheduler)
+        self.db = Status.from_json(db)
+
+    def __str__(self):
+        return f"FOSSology server status is: {self.status} (Scheduler: {self.scheduler.status} - DB: {self.db.status})"
+
+    @classmethod
+    def from_json(cls, json_dict):
+        return cls(**json_dict)
+
+
 def get_options(group: str = None, folder: Folder = None) -> str:
     options = ""
     if group:
