@@ -1,19 +1,50 @@
 # Copyright 2019-2021 Siemens AG
 # SPDX-License-Identifier: MIT
-
 import json
 import logging
+import re
 import time
 
 from tenacity import TryAgain, retry, retry_if_exception_type, stop_after_attempt
 
 from fossology.exceptions import AuthorizationError, FossologyApiError
-from fossology.obj import Licenses, Summary, Upload, get_options
+from fossology.obj import ClearingStatus, Folder, Licenses, Summary, Upload, get_options
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
 
+def list_uploads_parameters(
+    folder: Folder,
+    recursive: bool = True,
+    name: str = None,
+    status: ClearingStatus = None,
+    assignee: str = None,
+    since: str = None,
+) -> dict:
+    """Helper function to list of query parameters for GET /uploads endpoint"""
+    date_pattern = re.compile("^[0-9]{4}-[0-9]{2}-[0-9]{2}")
+    params = {}
+    if folder:
+        params["folderId"] = folder.id
+    if not recursive:
+        params["recursive"] = "false"
+    if name:
+        params["name"] = name
+    if status:
+        params["status"] = status.value
+    if assignee:
+        params["assignee"] = assignee
+    if since:
+        if not date_pattern.match(since):
+            logger.error(
+                f"Date format for 'since' query parameter {since} does not match expected format YYYY-MM-DD"
+            )
+        else:
+            params["since"] = since
+    return params
+
+
 class Uploads:
     """Class dedicated to all "uploads" related endpoints"""
 
@@ -36,10 +67,10 @@ class Uploads:
         :Examples:
 
         >>> # Wait up to 20 minutes until the upload is ready
-        >>> long_upload = detail_upload(1, 120)
+        >>> long_upload = detail_upload(1, wait_time=120) # doctest: +SKIP
 
         >>> # Wait up to 5 minutes until the upload is ready
-        >>> long_upload = detail_upload(1, 30)
+        >>> long_upload = detail_upload(1, wait_time=30) # doctest: +SKIP
 
         :param upload_id: the id of the upload
         :param group: the group the upload shall belong to
@@ -103,58 +134,58 @@ class Uploads:
 
         >>> from fossology import Fossology
         >>> from fossology.obj import AccessLevel
-        >>> foss = Fossology(FOSS_URL, FOSS_TOKEN, username)
+        >>> foss = Fossology(FOSS_URL, FOSS_TOKEN, username) # doctest: +SKIP
         >>> my_upload = foss.upload_file(
-                foss.rootFolder,
-                file="my-package.zip",
-                description="My product package",
-                access_level=AccessLevel.PUBLIC,
-            )
+        ...        foss.rootFolder,
+        ...        file="my-package.zip",
+        ...        description="My product package",
+        ...        access_level=AccessLevel.PUBLIC,
+        ...    )  # doctest: +SKIP
 
         :Example for a VCS upload:
 
         >>> vcs = {
-                "vcsType": "git",
-                "vcsUrl": "https://github.com/fossology/fossology-python",
-                "vcsName": "fossology-python-github-master",
-                "vcsUsername": "",
-                "vcsPassword": "",
-            }
+        ...        "vcsType": "git",
+        ...        "vcsUrl": "https://github.com/fossology/fossology-python",
+        ...        "vcsName": "fossology-python-github-master",
+        ...        "vcsUsername": "",
+        ...        "vcsPassword": "",
+        ...    }
         >>> vcs_upload = foss.upload_file(
-                foss.rootFolder,
-                vcs=vcs,
-                description="Upload from VCS",
-                access_level=AccessLevel.PUBLIC,
-            )
+        ...        foss.rootFolder,
+        ...        vcs=vcs,
+        ...        description="Upload from VCS",
+        ...        access_level=AccessLevel.PUBLIC,
+        ...    )  # doctest: +SKIP
 
         :Example for a URL upload:
 
         >>> url = {
-                "url": "https://github.com/fossology/fossology-python/archive/master.zip",
-                "name": "fossology-python-master.zip",
-                "accept": "zip",
-                "reject": "",
-                "maxRecursionDepth": "1",
-            }
+        ...        "url": "https://github.com/fossology/fossology-python/archive/master.zip",
+        ...        "name": "fossology-python-master.zip",
+        ...        "accept": "zip",
+        ...        "reject": "",
+        ...        "maxRecursionDepth": "1",
+        ...    }
         >>> url_upload = foss.upload_file(
-                foss.rootFolder,
-                url=url,
-                description="Upload from URL",
-                access_level=AccessLevel.PUBLIC,
-            )
+        ...        foss.rootFolder,
+        ...        url=url,
+        ...        description="Upload from URL",
+        ...        access_level=AccessLevel.PUBLIC,
+        ...    )  # doctest: +SKIP
 
         :Example for a SERVER upload:
 
         >>> server = {
-                "path": "/tmp/fossology-python",
-                "name": "fossology-python",
-            }
+        ...        "path": "/tmp/fossology-python",
+        ...        "name": "fossology-python",
+        ...    }
         >>> server_upload = foss.upload_file(
-                foss.rootFolder,
-                server=server,
-                description="Upload from SERVER",
-                access_level=AccessLevel.PUBLIC,
-            )
+        ...        foss.rootFolder,
+        ...        server=server,
+        ...        description="Upload from SERVER",
+        ...        access_level=AccessLevel.PUBLIC,
+        ...    )  # doctest: +SKIP
 
 
         :param folder: the upload Fossology folder
@@ -230,7 +261,9 @@ class Uploads:
 
         if response.status_code == 201:
             try:
-                upload = self.detail_upload(response.json()["message"], wait_time)
+                upload = self.detail_upload(
+                    response.json()["message"], group, wait_time
+                )
                 if upload.filesize:
                     logger.info(
                         f"Upload {upload.uploadname} ({upload.filesize}) "
@@ -404,26 +437,38 @@ class Uploads:
 
     def list_uploads(
         self,
-        folder=None,
-        group=None,
-        recursive=True,
+        folder: int = None,
+        group: str = None,
+        recursive: bool = True,
+        name: str = None,
+        status: ClearingStatus = None,
+        assignee: str = None,
+        since: str = None,
         page_size=100,
         page=1,
         all_pages=False,
     ):
-        """Get all uploads available to the registered user
+        """Get uploads according to filtering criteria (or all available)
 
         API Endpoint: GET /uploads
 
         :param folder: only list uploads from the given folder
         :param group: list uploads from a specific group (not only your own uploads) (default: None)
         :param recursive: wether to list uploads from children folders or not (default: True)
+        :param name: filter pattern for name and description
+        :param status: status of uploads
+        :param assignee: user name to which uploads are assigned to or "-me-" or "-unassigned-"
+        :param since: uploads since given date in YYYY-MM-DD format
         :param page_size: limit the number of uploads per page (default: 100)
         :param page: the number of the page to fetch uploads from (default: 1)
         :param all_pages: get all uploads (default: False)
         :type folder: Folder
         :type group: string
         :type recursive: boolean
+        :type name: str
+        :type status: ClearingStatus
+        :type assignee: str
+        :type since: str
         :type page_size: int
         :type page: int
         :type all_pages: boolean
@@ -432,15 +477,18 @@ class Uploads:
         :raises FossologyApiError: if the REST call failed
         :raises AuthorizationError: if the user can't access the group
         """
-        params = {}
         headers = {"limit": str(page_size)}
         if group:
             headers["groupName"] = group
-        if folder:
-            params["folderId"] = folder.id
-        if not recursive:
-            params["recursive"] = "false"
 
+        params = list_uploads_parameters(
+            folder=folder,
+            recursive=recursive,
+            name=name,
+            status=status,
+            assignee=assignee,
+            since=since,
+        )
         uploads_list = list()
         if all_pages:
             # will be reset after the total number of pages has been retrieved from the API
